@@ -4,8 +4,8 @@ distributed under the Creative Commons Attribution-ShareAlike 3.0
 Unported License. */
 
 #include "ip-tools.h"
-int n_china_ips = 2787;
-ip_block_t china_ips[2787] = {
+int n_china_ips = 2748;
+ip_block_t china_ips[2748] = {
 {0x1000100,0x10003FF},
 {0x1000800,0x1000FFF},
 {0x1002000,0x1003FFF},
@@ -31,7 +31,7 @@ ip_block_t china_ips[2787] = {
 {0x1CA0000,0x1CFFFFF},
 {0x50A4628,0x50A462B},
 {0x50A4650,0x50A4657},
-{0x50A47E9,0x50A47E9},
+{0x50A4810,0x50A4817},
 {0x50A4850,0x50A485F},
 {0x50A4A28,0x50A4A9F},
 {0x50A4AC0,0x50A4ADF},
@@ -45,13 +45,8 @@ ip_block_t china_ips[2787] = {
 {0x50A5630,0x50A5637},
 {0x50A5648,0x50A564B},
 {0x50A56A0,0x50A56A7},
-{0x50A5702,0x50A5702},
 {0x50A5760,0x50A5767},
 {0x50A5780,0x50A5787},
-{0x50A57C0,0x50A57C1},
-{0x50A57D6,0x50A57D7},
-{0x50A57F4,0x50A57F6},
-{0x50A57FC,0x50A57FD},
 {0x50A58F0,0x50A58FF},
 {0x50A5AE8,0x50A5AEF},
 {0x50A6148,0x50A614B},
@@ -65,27 +60,23 @@ ip_block_t china_ips[2787] = {
 {0x50A6F08,0x50A6F0F},
 {0x50A6F38,0x50A6F3F},
 {0x50A7218,0x50A721B},
-{0x50A729F,0x50A729F},
 {0x50A7428,0x50A7437},
 {0x50A7460,0x50A746F},
 {0x50A7770,0x50A7777},
 {0x50A78E8,0x50A78EF},
 {0x50A7A08,0x50A7A0F},
-{0x50A7A3E,0x50A7A3E},
 {0x50A7AF0,0x50A7AF7},
 {0x53F1900,0x53F19FF},
+{0x5843600,0x58436FF},
 {0x5990044,0x5990047},
-{0x59900A0,0x59900AF},
 {0x5990450,0x5990457},
-{0x59904F7,0x59904F7},
-{0x59907FE,0x59907FE},
+{0x5990478,0x599047F},
+{0x5990AA0,0x5990AA7},
 {0x5990AB8,0x5990ABF},
 {0x5990B30,0x5990B37},
-{0x5990F88,0x5990F8F},
 {0x5991158,0x599115F},
-{0x59912A8,0x59912AB},
 {0x5991388,0x599138F},
-{0x5991418,0x599141B},
+{0x59913F0,0x59913F7},
 {0x5991490,0x5991497},
 {0x59914F8,0x59914FF},
 {0x5C6FBA8,0x5C6FBAF},
@@ -136,11 +127,11 @@ ip_block_t china_ips[2787] = {
 {0x1B900000,0x1B90FFFF},
 {0x1B940000,0x1B9FFFFF},
 {0x1BB80000,0x1BE3FFFF},
-{0x1FC90004,0x1FC90007},
-{0x1FC90400,0x1FC904DF},
+{0x1FBB4200,0x1FBB42FF},
 {0x1FD68C80,0x1FD68CBF},
 {0x1FD69300,0x1FD693FF},
 {0x1FD69A00,0x1FD69AFF},
+{0x1FDC1EE0,0x1FDC1EFF},
 {0x24000000,0x240003FF},
 {0x24000800,0x2401FFFF},
 {0x24040000,0x2407FFFF},
@@ -152,21 +143,15 @@ ip_block_t china_ips[2787] = {
 {0x24600000,0x24DFFFFF},
 {0x24F80000,0x24FBFFFF},
 {0x24FE0000,0x24FEFFFF},
-{0x253A4340,0x253A4347},
+{0x253A4500,0x253A450F},
 {0x253A46A0,0x253A46BF},
 {0x253A46E8,0x253A46EB},
-{0x253A4A70,0x253A4A77},
 {0x253A4B30,0x253A4B37},
-{0x253A4D48,0x253A4D4F},
-{0x253A5426,0x253A5426},
 {0x253A54F0,0x253A54F7},
-{0x253A5780,0x253A5787},
-{0x253A5B44,0x253A5B47},
+{0x253A5540,0x253A555F},
+{0x253A5A60,0x253A5A7F},
 {0x253A5B58,0x253A5B5F},
 {0x253A5D28,0x253A5D37},
-{0x253A5E78,0x253A5E7F},
-{0x253A5E81,0x253A5E81},
-{0x253A5EC0,0x253A5EC7},
 {0x253A5FF0,0x253A5FF7},
 {0x253A61EC,0x253A61EF},
 {0x253A6478,0x253A647F},
@@ -322,10 +307,12 @@ ip_block_t china_ips[2787] = {
 {0x431666A8,0x431666AF},
 {0x432BE2E8,0x432BE2EF},
 {0x432BE6C8,0x432BE6CF},
+{0x43D7F148,0x43D7F14F},
 {0x43DE9E1F,0x43DE9E5E},
 {0x444465C8,0x444465CF},
 {0x444465E0,0x444465E7},
-{0x44446878,0x4444687F},
+{0x44446650,0x4444665F},
+{0x44446668,0x4444666F},
 {0x44446988,0x44446997},
 {0x444469A0,0x444469CF},
 {0x444469D8,0x444469DF},
@@ -334,11 +321,6 @@ ip_block_t china_ips[2787] = {
 {0x4447FA60,0x4447FA7F},
 {0x44A87080,0x44A870BF},
 {0x44AB6600,0x44AB67FF},
-{0x454021A0,0x454021A0},
-{0x454021A3,0x454021A3},
-{0x454021A6,0x454021A6},
-{0x454021B1,0x454021B1},
-{0x454022D9,0x454022D9},
 {0x455A6388,0x455A638F},
 {0x45C519BC,0x45C519BF},
 {0x48017930,0x4801793F},
@@ -409,15 +391,8 @@ ip_block_t china_ips[2787] = {
 {0x4E18CB28,0x4E18CB2F},
 {0x4E18CE28,0x4E18CE2F},
 {0x515C7DF0,0x515C7DFF},
-{0x515F96A0,0x515F96BF},
-{0x515F9900,0x515F993F},
-{0x515F9AC0,0x515F9B1F},
-{0x54167F10,0x54167F17},
 {0x54C8C800,0x54C8C87F},
 {0x54C926C0,0x54C926FF},
-{0x55191BD1,0x55191BD1},
-{0x5519FE1D,0x5519FE1D},
-{0x5519FE21,0x5519FE22},
 {0x57FECE00,0x57FECFFF},
 {0x5BBEAD00,0x5BBEADFF},
 {0x5BC4E800,0x5BC4EBFF},
@@ -539,6 +514,15 @@ ip_block_t china_ips[2787] = {
 {0x67112800,0x67112BFF},
 {0x67117800,0x67117BFF},
 {0x6711A000,0x6711A3FF},
+{0x6711CC00,0x6711CFFF},
+{0x6711E400,0x6711E7FF},
+{0x6712C000,0x6712C3FF},
+{0x6712D000,0x6712D7FF},
+{0x6712E000,0x6712E3FF},
+{0x67130C00,0x67130FFF},
+{0x67132800,0x67132FFF},
+{0x67134000,0x67134BFF},
+{0x6713E800,0x6713EBFF},
 {0x67140C00,0x67140FFF},
 {0x67142000,0x671423FF},
 {0x67147000,0x671473FF},
@@ -560,6 +544,20 @@ ip_block_t china_ips[2787] = {
 {0x6717A000,0x6717A7FF},
 {0x6717B000,0x6717B3FF},
 {0x6717E400,0x6717E7FF},
+{0x67187400,0x671877FF},
+{0x67188000,0x671883FF},
+{0x67189000,0x671893FF},
+{0x6718B000,0x6718B3FF},
+{0x6718B800,0x6718BBFF},
+{0x6718DC00,0x6718DFFF},
+{0x6718E400,0x6718E7FF},
+{0x6718F800,0x6718FFFF},
+{0x67190800,0x671909FF},
+{0x67191400,0x67192BFF},
+{0x67193000,0x671933FF},
+{0x67194000,0x671947FF},
+{0x67199400,0x671997FF},
+{0x67199C00,0x67199FFF},
 {0x671C0400,0x671C0BFF},
 {0x671CCC00,0x671CCFFF},
 {0x671D1000,0x671D13FF},
@@ -577,7 +575,7 @@ ip_block_t china_ips[2787] = {
 {0x671FA800,0x671FABFF},
 {0x671FC800,0x671FCBFF},
 {0x67F41000,0x67F413FF},
-{0x67F43800,0x67F45BFF},
+{0x67F43800,0x67F457FF},
 {0x67F49400,0x67F497FF},
 {0x67F4A400,0x67F4A7FF},
 {0x67F4E800,0x67F4EBFF},
@@ -605,6 +603,8 @@ ip_block_t china_ips[2787] = {
 {0x6A6C0000,0x6A7FFFFF},
 {0x6ABB2000,0x6ABB22AF},
 {0x6ABB22B1,0x6ABB27FF},
+{0x6ABB3000,0x6ABB37FF},
+{0x6ABB6000,0x6ABB67FF},
 {0x6AE00000,0x6AEFFFFF},
 {0x6C3EB940,0x6C3EB97F},
 {0x6CAE4260,0x6CAE4277},
@@ -1076,7 +1076,6 @@ ip_block_t china_ips[2787] = {
 {0x907B0000,0x907BFFFF},
 {0x90FF0000,0x90FFFFFF},
 {0x92F77A00,0x92F77A0F},
-{0x93F3D800,0x93F3D8FF},
 {0x93F3E000,0x93F3FFFF},
 {0x96000000,0x9600FFFF},
 {0x96730000,0x9673FFFF},
@@ -1105,17 +1104,15 @@ ip_block_t china_ips[2787] = {
 {0x9FFD8960,0x9FFD8967},
 {0x9FFD89AC,0x9FFD89AF},
 {0x9FFD8B18,0x9FFD8B1F},
+{0x9FFD8B48,0x9FFD8B4B},
 {0x9FFD8BB8,0x9FFD8BBF},
+{0x9FFD8BD0,0x9FFD8BD7},
 {0x9FFD8CA8,0x9FFD8CAB},
-{0x9FFD8DA0,0x9FFD8DA7},
-{0x9FFD8E50,0x9FFD8E57},
 {0x9FFD9078,0x9FFD907F},
 {0x9FFD9220,0x9FFD9227},
 {0x9FFD9280,0x9FFD92A7},
-{0x9FFD9381,0x9FFD9381},
 {0x9FFD95F0,0x9FFD95F7},
 {0x9FFD9740,0x9FFD975F},
-{0x9FFD9875,0x9FFD9875},
 {0xA03E0A00,0xA03E0AFF},
 {0xA1CF0000,0xA1CFFFFF},
 {0xA2690000,0xA269FFFF},
@@ -1305,14 +1302,15 @@ ip_block_t china_ips[2787] = {
 {0xB7B80000,0xB7FFFFFF},
 {0xB85F2360,0xB85F237F},
 {0xB8ACB5F0,0xB8ACB5F7},
-{0xB9086810,0xB908683F},
+{0xB9086820,0xB908683F},
 {0xB9086860,0xB9086867},
 {0xB9086880,0xB90868EF},
-{0xBC8A4F8E,0xBC8A4F8E},
-{0xBC8A4F94,0xBC8A4F94},
-{0xBC8A5376,0xBC8A5376},
-{0xBC8A78A9,0xBC8A78A9},
+{0xB9086AC0,0xB9086AFF},
+{0xB90C9474,0xB90C9477},
+{0xB9193301,0xB9193340},
+{0xB9193380,0xB91933FF},
 {0xC0001100,0xC000111F},
+{0xC0372E00,0xC0372EFF},
 {0xC04AE030,0xC04AE03F},
 {0xC04AE060,0xC04AE07F},
 {0xC04AE090,0xC04AE0E7},
@@ -1349,29 +1347,13 @@ ip_block_t china_ips[2787] = {
 {0xC04AFC40,0xC04AFCBF},
 {0xC04AFD00,0xC04AFE7F},
 {0xC04AFF00,0xC04AFFFF},
+{0xC066CC00,0xC066CCFF},
 {0xC07C9A00,0xC07C9AFF},
 {0xC0891F00,0xC0891FFF},
 {0xC097FF00,0xC097FFFF},
 {0xC0A15C00,0xC0A15FFF},
 {0xC0BCAA00,0xC0BCAAFF},
 {0xC1DC7000,0xC1DC70FF},
-{0xC275652D,0xC275652D},
-{0xC2756537,0xC2756537},
-{0xC275672B,0xC275672B},
-{0xC275673A,0xC275673A},
-{0xC275674E,0xC275674F},
-{0xC2756778,0xC2756778},
-{0xC275677B,0xC275677B},
-{0xC2756796,0xC2756796},
-{0xC275679A,0xC275679B},
-{0xC27567B5,0xC27567B5},
-{0xC27567BD,0xC27567BD},
-{0xC27567C3,0xC27567C3},
-{0xC27567CE,0xC27567CE},
-{0xC27567D7,0xC27567D7},
-{0xC27567DA,0xC27567DB},
-{0xC27567E6,0xC27567E6},
-{0xC2757765,0xC2757765},
 {0xC370A714,0xC370A717},
 {0xC370A738,0xC370A73B},
 {0xC370A754,0xC370A757},
@@ -1379,7 +1361,6 @@ ip_block_t china_ips[2787] = {
 {0xC370B114,0xC370B117},
 {0xC370B120,0xC370B123},
 {0xC370B17C,0xC370B17F},
-{0xC370BF0C,0xC370BF0C},
 {0xC60738C0,0xC60738CF},
 {0xC60F43F0,0xC60F43F7},
 {0xC60F4540,0xC60F457F},
@@ -1471,15 +1452,8 @@ ip_block_t china_ips[2787] = {
 {0xC7BC6F70,0xC7BC6F7F},
 {0xC7BC6F88,0xC7BC6F9F},
 {0xC7BC6FB0,0xC7BC6FBF},
-{0xC7E5E3A0,0xC7E5E3BF},
 {0xC7E74000,0xC7E7400F},
 {0xC7E74020,0xC7E7405F},
-{0xC7E74065,0xC7E74066},
-{0xC7E74068,0xC7E7406F},
-{0xC7E74071,0xC7E74074},
-{0xC7E74076,0xC7E74076},
-{0xC7E74078,0xC7E7407A},
-{0xC7E7407D,0xC7E7407D},
 {0xC7E74080,0xC7E740BF},
 {0xC7E74100,0xC7E741DF},
 {0xC7E74200,0xC7E74217},
@@ -1568,6 +1542,8 @@ ip_block_t china_ips[2787] = {
 {0xCA0EEB00,0xCA0EEFFF},
 {0xCA0EF600,0xCA0EF6FF},
 {0xCA0EFB00,0xCA0EFBFF},
+{0xCA144200,0xCA1442FF},
+{0xCA144F00,0xCA144FFF},
 {0xCA145700,0xCA145AFF},
 {0xCA145E00,0xCA145FFF},
 {0xCA147200,0xCA1472FF},
@@ -1619,6 +1595,8 @@ ip_block_t china_ips[2787] = {
 {0xCA2C9200,0xCA2C93FF},
 {0xCA2D0000,0xCA2D02FF},
 {0xCA2D0F00,0xCA2D1FFF},
+{0xCA2D8100,0xCA2D81B3},
+{0xCA2D81B6,0xCA2D81FF},
 {0xCA2E1000,0xCA2E12FF},
 {0xCA2E1400,0xCA2E15FF},
 {0xCA2E2000,0xCA2E3FFF},
@@ -2539,7 +2517,7 @@ ip_block_t china_ips[2787] = {
 {0xCB806000,0xCB807FFF},
 {0xCB80E000,0xCB80E7FF},
 {0xCB810800,0xCB810FFF},
-{0xCB822000,0xCB823FFF},
+{0xCB822000,0xCB822FFF},
 {0xCB842000,0xCB843FFF},
 {0xCB86F000,0xCB86F7FF},
 {0xCB876000,0xCB877FFF},
@@ -2582,7 +2560,6 @@ ip_block_t china_ips[2787] = {
 {0xCBBE6000,0xCBBE6FFF},
 {0xCBBEF900,0xCBBEF9FF},
 {0xCBBF0000,0xCBBF01FF},
-{0xCBBF1000,0xCBBF1FFF},
 {0xCBBF4000,0xCBBF7FFF},
 {0xCBBF9000,0xCBBF9FFF},
 {0xCBC00000,0xCBC01FFF},
@@ -2615,7 +2592,6 @@ ip_block_t china_ips[2787] = {
 {0xCE49E340,0xCE49E37F},
 {0xCE49E418,0xCE49E41F},
 {0xCE49F620,0xCE49F62F},
-{0xCE6BFE48,0xCE6BFE4F},
 {0xCE7DAE10,0xCE7DAE17},
 {0xCEA875A0,0xCEA875AF},
 {0xCEB6C7D0,0xCEB6C7D7},
@@ -2667,7 +2643,8 @@ ip_block_t china_ips[2787] = {
 {0xD2108000,0xD210BFFF},
 {0xD2150000,0xD216FFFF},
 {0xD2172000,0xD2173FFF},
-{0xD2190000,0xD22FFFFF},
+{0xD2190000,0xD21FD203},
+{0xD21FD208,0xD22FFFFF},
 {0xD2308800,0xD2308FFF},
 {0xD2330000,0xD2346CFF},
 {0xD2346E00,0xD235FFFF},
@@ -2689,18 +2666,9 @@ ip_block_t china_ips[2787] = {
 {0xD43FB5B4,0xD43FB5BB},
 {0xD43FB5C8,0xD43FB5CB},
 {0xD43FB5E0,0xD43FB5E3},
-{0xD43FB704,0xD43FB704},
-{0xD43FB709,0xD43FB70A},
-{0xD43FB70F,0xD43FB70F},
-{0xD43FB713,0xD43FB713},
-{0xD43FB717,0xD43FB717},
-{0xD43FB71C,0xD43FB71C},
-{0xD43FB73A,0xD43FB73A},
-{0xD43FB73E,0xD43FB73E},
-{0xD43FB740,0xD43FB740},
-{0xD43FB744,0xD43FB744},
 {0xD43FB7D4,0xD43FB7DB},
 {0xD43FB7E4,0xD43FB7E7},
+{0xD80FAC00,0xD80FACFF},
 {0xD80FEEA0,0xD80FEEBF},
 {0xD8263390,0xD8263393},
 {0xD85E6900,0xD85E69FF},
@@ -2725,13 +2693,6 @@ ip_block_t china_ips[2787] = {
 {0xD9078D00,0xD9078D27},
 {0xD9078D30,0xD9078F00},
 {0xD9086500,0xD90865FF},
-{0xD9ACB990,0xD9ACB990},
-{0xD9ACB9D7,0xD9ACB9D7},
-{0xD9ACB9D9,0xD9ACB9E2},
-{0xD9ACB9E6,0xD9ACB9E6},
-{0xD9ACB9E8,0xD9ACB9E8},
-{0xD9ACB9EB,0xD9ACB9ED},
-{0xD9ACB9EF,0xD9ACB9F0},
 {0xDA000000,0xDA1FFFFF},
 {0xDA380000,0xDA63FFFF},
 {0xDA645800,0xDA64FFFF},
